
import { localize } from '../../../../nls.js';
import { RawContextKey, ContextKeyExpr } from '../../../../platform/contextkey/common/contextkey.js';
import { IsWebContext } from '../../../../platform/contextkey/common/contextkeys.js';
import { RemoteNameContext } from '../../../common/contextkeys.js';
import { ChatMode } from './constants.js';

var ChatContextKeys;
(function (ChatContextKeys) {
    ChatContextKeys.responseVote = ( new RawContextKey(
        'chatSessionResponseVote',
        '',
        { type: 'string', description: ( localize(
            5005,
            "When the response has been voted up, is set to 'up'. When voted down, is set to 'down'. Otherwise an empty string."
        )) }
    ));
    ChatContextKeys.responseDetectedAgentCommand = ( new RawContextKey(
        'chatSessionResponseDetectedAgentOrCommand',
        false,
        { type: 'boolean', description: ( localize(5006, "When the agent or command was automatically detected")) }
    ));
    ChatContextKeys.responseSupportsIssueReporting = ( new RawContextKey(
        'chatResponseSupportsIssueReporting',
        false,
        { type: 'boolean', description: ( localize(5007, "True when the current chat response supports issue reporting.")) }
    ));
    ChatContextKeys.responseIsFiltered = ( new RawContextKey(
        'chatSessionResponseFiltered',
        false,
        { type: 'boolean', description: ( localize(5008, "True when the chat response was filtered out by the server.")) }
    ));
    ChatContextKeys.responseHasError = ( new RawContextKey(
        'chatSessionResponseError',
        false,
        { type: 'boolean', description: ( localize(5009, "True when the chat response resulted in an error.")) }
    ));
    ChatContextKeys.requestInProgress = ( new RawContextKey(
        'chatSessionRequestInProgress',
        false,
        { type: 'boolean', description: ( localize(5010, "True when the current request is still in progress.")) }
    ));
    ChatContextKeys.isRequestPaused = ( new RawContextKey(
        'chatRequestIsPaused',
        false,
        { type: 'boolean', description: ( localize(5011, "True when the current request is paused.")) }
    ));
    ChatContextKeys.canRequestBePaused = ( new RawContextKey(
        'chatCanRequestBePaused',
        false,
        { type: 'boolean', description: ( localize(5012, "True when the current request can be paused.")) }
    ));
    ChatContextKeys.isResponse = ( new RawContextKey('chatResponse', false, { type: 'boolean', description: ( localize(5013, "The chat item is a response.")) }));
    ChatContextKeys.isRequest = ( new RawContextKey('chatRequest', false, { type: 'boolean', description: ( localize(5014, "The chat item is a request")) }));
    ChatContextKeys.itemId = ( new RawContextKey('chatItemId', '', { type: 'string', description: ( localize(5015, "The id of the chat item.")) }));
    ChatContextKeys.lastItemId = ( new RawContextKey('chatLastItemId', [], { type: 'string', description: ( localize(5016, "The id of the last chat item.")) }));
    ChatContextKeys.editApplied = ( new RawContextKey('chatEditApplied', false, { type: 'boolean', description: ( localize(5017, "True when the chat text edits have been applied.")) }));
    ChatContextKeys.inputHasText = ( new RawContextKey('chatInputHasText', false, { type: 'boolean', description: ( localize(5018, "True when the chat input has text.")) }));
    ChatContextKeys.inputHasFocus = ( new RawContextKey('chatInputHasFocus', false, { type: 'boolean', description: ( localize(5019, "True when the chat input has focus.")) }));
    ChatContextKeys.inChatInput = ( new RawContextKey('inChatInput', false, { type: 'boolean', description: ( localize(5020, "True when focus is in the chat input, false otherwise.")) }));
    ChatContextKeys.inChatSession = ( new RawContextKey('inChat', false, { type: 'boolean', description: ( localize(5021, "True when focus is in the chat widget, false otherwise.")) }));
    ChatContextKeys.hasPromptFile = ( new RawContextKey(
        'chatPromptFileAttached',
        false,
        { type: 'boolean', description: ( localize(5022, "True when the chat has a prompt file attached.")) }
    ));
    ChatContextKeys.chatMode = ( new RawContextKey('chatMode', ChatMode.Ask, { type: 'string', description: ( localize(5023, "The current chat mode.")) }));
    ChatContextKeys.supported = ( ContextKeyExpr.or(( IsWebContext.negate()), ( RemoteNameContext.notEqualsTo(''))));
    ChatContextKeys.enabled = ( new RawContextKey('chatIsEnabled', false, { type: 'boolean', description: ( localize(
        5024,
        "True when chat is enabled because a default chat participant is activated with an implementation."
    )) }));
    ChatContextKeys.extensionParticipantRegistered = ( new RawContextKey(
        'chatPanelExtensionParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(
            5025,
            "True when a default chat participant is registered for the panel from an extension."
        )) }
    ));
    ChatContextKeys.panelParticipantRegistered = ( new RawContextKey(
        'chatPanelParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(5026, "True when a default chat participant is registered for the panel.")) }
    ));
    ChatContextKeys.editingParticipantRegistered = ( new RawContextKey(
        'chatEditingParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(5027, "True when a default chat participant is registered for editing.")) }
    ));
    ChatContextKeys.chatEditingCanUndo = ( new RawContextKey(
        'chatEditingCanUndo',
        false,
        { type: 'boolean', description: ( localize(
            5028,
            "True when it is possible to undo an interaction in the editing panel."
        )) }
    ));
    ChatContextKeys.chatEditingCanRedo = ( new RawContextKey(
        'chatEditingCanRedo',
        false,
        { type: 'boolean', description: ( localize(
            5029,
            "True when it is possible to redo an interaction in the editing panel."
        )) }
    ));
    ChatContextKeys.extensionInvalid = ( new RawContextKey(
        'chatExtensionInvalid',
        false,
        { type: 'boolean', description: ( localize(
            5030,
            "True when the installed chat extension is invalid and needs to be updated."
        )) }
    ));
    ChatContextKeys.inputCursorAtTop = ( new RawContextKey('chatCursorAtTop', false));
    ChatContextKeys.inputHasAgent = ( new RawContextKey('chatInputHasAgent', false));
    ChatContextKeys.location = ( new RawContextKey('chatLocation', undefined));
    ChatContextKeys.inQuickChat = ( new RawContextKey('quickChatHasFocus', false, { type: 'boolean', description: ( localize(5031, "True when the quick chat UI has focus, false otherwise.")) }));
    ChatContextKeys.hasFileAttachments = ( new RawContextKey(
        'chatHasFileAttachments',
        false,
        { type: 'boolean', description: ( localize(5032, "True when the chat has file attachments.")) }
    ));
    ChatContextKeys.languageModelsAreUserSelectable = ( new RawContextKey(
        'chatModelsAreUserSelectable',
        false,
        { type: 'boolean', description: ( localize(5033, "True when the chat model can be selected manually by the user.")) }
    ));
    ChatContextKeys.Setup = {
        hidden: ( new RawContextKey('chatSetupHidden', false, true)),
        installed: ( new RawContextKey('chatSetupInstalled', false, true)),
        disabled: ( new RawContextKey('chatSetupDisabled', false, true))
    };
    ChatContextKeys.Entitlement = {
        signedOut: ( new RawContextKey('chatSetupSignedOut', false, true)),
        canSignUp: ( new RawContextKey('chatPlanCanSignUp', false, true)),
        limited: ( new RawContextKey('chatPlanLimited', false, true)),
        pro: ( new RawContextKey('chatPlanPro', false, true)),
        proPlus: ( new RawContextKey('chatPlanProPlus', false, true)),
        business: ( new RawContextKey('chatPlanBusiness', false, true)),
        enterprise: ( new RawContextKey('chatPlanEnterprise', false, true))
    };
    ChatContextKeys.chatQuotaExceeded = ( new RawContextKey('chatQuotaExceeded', false, true));
    ChatContextKeys.completionsQuotaExceeded = ( new RawContextKey('completionsQuotaExceeded', false, true));
    ChatContextKeys.Editing = {
        agentModeDisallowed: ( new RawContextKey(
            'chatAgentModeDisallowed',
            undefined,
            { type: 'boolean', description: ( localize(5034, "True when agent mode is not allowed.")) }
        )),
        hasToolConfirmation: ( new RawContextKey(
            'chatHasToolConfirmation',
            false,
            { type: 'boolean', description: ( localize(5035, "True when a tool confirmation is present.")) }
        )),
    };
    ChatContextKeys.Tools = {
        toolsCount: ( new RawContextKey('toolsCount', 0, { type: 'number', description: ( localize(5036, "The count of tools available in the chat.")) }))
    };
})(ChatContextKeys || (ChatContextKeys = {}));
var ChatContextKeyExprs;
(function (ChatContextKeyExprs) {
    ChatContextKeyExprs.inEditingMode = ( ContextKeyExpr.or(( ChatContextKeys.chatMode.isEqualTo(ChatMode.Edit)), ( ChatContextKeys.chatMode.isEqualTo(ChatMode.Agent))));
})(ChatContextKeyExprs || (ChatContextKeyExprs = {}));

export { ChatContextKeyExprs, ChatContextKeys };
